@@ -5,12 +5,13 @@ from django.views.generic.base import TemplateView
 from registration.backends.default.views import ActivationView
 from registration.backends.default.views import RegistrationView
 
-from .views import UserProfileView
+from .views import UserProfileView, DeleteUserView
 
 
 urlpatterns = patterns(
     '',
     url(r'^profile/', UserProfileView.as_view(), name="account_profile"),
+    url(r'^delete/', DeleteUserView.as_view(), name="account_delete"),
     # registration start
     url(r'^activate/complete/$',
         TemplateView.as_view(template_name='registration/activation_complete.html'),
