@@ -10,6 +10,7 @@ logger = logging.getLogger(__name__)
 import time
 
 from .main.dnstools import put_ip_into_session
+from .main.iptools import normalize_ip
 
 from django.conf import settings
 
@@ -36,7 +37,7 @@ def update_ips(request):
     s = request.session
     t_now = int(time.time())
     # update and keep fresh using info from the request we have anyway:
-    ipaddr = request.META['REMOTE_ADDR']
+    ipaddr = normalize_ip(request.META['REMOTE_ADDR'])
     put_ip_into_session(s, ipaddr, max_age=MAX_IP_AGE / 2)
     # remove stale data to not show outdated IPs (e.g. after losing IPv6 connectivity):
     for key in ['ipv4', 'ipv6', ]:
