@@ -3,7 +3,7 @@ reinitialize the test user account (and clean up)
 """
 
 from django.conf import settings
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.core.management.base import NoArgsCommand
 
 
@@ -11,14 +11,15 @@ class Command(NoArgsCommand):
     help = 'reinitialize the test user'
 
     def handle_noargs(self, **options):
+        user_model = get_user_model()
         try:
-            u = User.objects.get(username='test')
+            u = user_model.objects.get(username='test')
             # delete test user and (via CASCADE behaviour) everything that
             # points to it (has user as ForeignKey), e.g. via created_by.
             u.delete()
-        except User.DoesNotExist:
+        except user_model.DoesNotExist:
             pass
         # create a fresh test user
-        u = User.objects.create_user('test', settings.DEFAULT_FROM_EMAIL, 'test')
+        u = user_model.objects.create_user('test', settings.DEFAULT_FROM_EMAIL, 'test')
         u.save()
         self.stdout.write('Successfully reinitialized the test user')
