@@ -35,5 +35,5 @@ INSTALLED_APPS += (
 LANGUAGES += (
     # note: for the development install we also offer unfinished translations:
     ('pl', gettext_noop('Polish')),
-    ('zh-cn', gettext_noop('Chinese (China)')),
+    # ('zh-cn', gettext_noop('Chinese (China)')),
 )
